/*
 *  LibRoadnav
 *  Angle.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef INCLUDED_ANGLE_H_
#define INCLUDED_ANGLE_H_

#include <wx/string.h>

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Represents an angle
///
//////////////////////////////////////////////////////////////////////////////
class Angle
{
public:
   //------------------------------------------------------------------------
   // Default constructor
   Angle(double angle = 0.);

   //------------------------------------------------------------------------
   Angle(short deg,unsigned short min,double sec);

   //------------------------------------------------------------------------
   Angle(unsigned short deg, unsigned short min,double sec,char dir);

   //------------------------------------------------------------------------
   // Copy constructor
   Angle(const Angle& rOther);

   //------------------------------------------------------------------------
   // Destructor
   virtual ~Angle();

   // GROUP: OPERATORS

   //------------------------------------------------------------------------
   // Assignment operator
   // Returns reference to itself
   Angle& operator = (const Angle& rOther);
   Angle& operator = (double angle);

   Angle operator+(const Angle& rOther) const;
   Angle operator-(const Angle& rOther) const;
   Angle operator*(double scalar) const;
   Angle operator/(double scalar) const;

   Angle& operator+=(const Angle& rOther);
   Angle& operator-=(const Angle& rOther);
   Angle& operator*=(double scalar);
   Angle& operator/=(double scalar);

   Angle operator-() const;


   //------------------------------------------------------------------------
   // Normalizes angle to the range [0, 2*PI).
   void Normalize();

   // GROUP: ACCESS

   //------------------------------------------------------------------------
   void SetAngle(double angle);

   //------------------------------------------------------------------------
   void SetAngle(short deg,unsigned short min,double sec);

   //------------------------------------------------------------------------
   double AsDouble() const;

   //------------------------------------------------------------------------
   // Returns a string representation of the angle (DMS format).  If
   // <i>bSigned</i> is <b>true</b> the angle is signed,  otherwise it
   // is written with a Left/Right direction specifier.  If bFull is
   // true, the full DMS format is written, if false, only the degree
   // is written if minutes and seconds are zero.
   // If bSymbols is true, the degree, minute, and second symbols are
   // included in the string.
   wxString AsString(bool bSigned,bool bFull = true,bool bSymbols = false) const;

   //------------------------------------------------------------------------
   // Converts a string in the format [+|-]ddd [[mm] [ss.s]] or dd [[mm] [ss.s]] {L|R}
   // to a Angle.  Returns true if successfule,  otherwise false.
   static bool AngleFromString(const char* str,Angle* pCAngle);

   // GROUP: INQUIRY

protected:
   // GROUP: DATA MEMBERS
   // GROUP: LIFECYCLE
   // GROUP: OPERATORS
   // GROUP: OPERATIONS
   void MakeCopy(const Angle& rOther);
   void MakeAssignment(const Angle& rOther);

   // GROUP: ACCESS
   // GROUP: INQUIRY

private:
   // GROUP: DATA MEMBERS
   double m_Angle;
};

// INLINE METHODS
//

// EXTERNAL REFERENCES
//

bool operator == (const Angle& a,const Angle& b);
bool operator != (const Angle& a,const Angle& b);
bool operator  > (const Angle& a,const Angle& b);
bool operator  < (const Angle& a,const Angle& b);
bool operator >= (const Angle& a,const Angle& b);
bool operator <= (const Angle& a,const Angle& b);

#endif // INCLUDED_ANGLE_H_
