/*
 *  LibRoadnav
 *  DetailSettings.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains the DetailSettings class, a class representing the various
/// settings for a particular detail level and feature type (e.g. line width,
/// text color, etc.)
///
//////////////////////////////////////////////////////////////////////////////

#ifndef DETAILSETTINGS_H
#define DETAILSETTINGS_H

#include <wx/config.h>

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Specifies various appearance settings
///
//////////////////////////////////////////////////////////////////////////////
class DetailSettings
{
	public:
		DetailSettings();
		bool Load(wxConfigBase* pConfig);
		void Save(wxConfigBase* pConfig) const;

		/// Line/dot color
		wxColour m_clrLine;
		
		/// Line/dot width in pixels
		int m_iWidth;
		
		/// Line style (wxSOLID, etc.)
		int m_iStyle;

		/// true = only use the start and end points of a polygon, false = draw all lines of the polygon
		bool m_bFastLine;

		/// true = railroad style markings, false = normal lines
		bool m_bRailroadStyle;


		/// Text color
		wxColour m_clrText;
		
		/// Label font size
		int m_iFontSize;


		/// Boolean - should the text be visible?
		bool m_bTextVisible;
		
		/// Boolean - should the line/dot be visible?
		bool m_bLineVisible;

		
		/// This is used with one-way roads to specify how far
		/// apart the arrow heads should be.
		int m_iArrowSpacing;
};

#endif
