/*
 *  LibRoadnav
 *  MapControlDataImporter_GNIS.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Imports GNIS data in columnar format into the Roadnav tile-layers
///
//////////////////////////////////////////////////////////////////////////////

#ifndef MAPCONTROLDATAIMPORTER_GNIS_H
#define MAPCONTROLDATAIMPORTER_GNIS_H

#include <wx/datetime.h>

#include <map>
#include <vector>

#include "Constants.h"
#include "Point.h"
#include "MapControlDataEntry_Std.h"
#include "MapControlData.h"
#include "MapControlDataImporter.h"
#include "ProgressDialog.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Imports GNIS data in columnar format (deprecated)
///
//////////////////////////////////////////////////////////////////////////////
class MapControlDataImporter_GNIS : public MapControlDataImporter
{
	public: // public functions
		MapControlDataImporter_GNIS(char * pszSource = NULL);
		virtual ~MapControlDataImporter_GNIS();
	
		static bool IsGNISStateLoaded(wxString strState);
		bool DownloadGNISStates(IMapControlData * pData, std::vector<wxString> vstrStates, ProgressDialog * pdlgProgress = NULL, int iProgressStart = 0, int iProgressTicks = 1);
		bool DownloadGNISState(IMapControlData * pData, wxString strState, ProgressDialog * pdlgProgress = NULL, int iProgressStart = 0, int iProgressTicks = 1);

		virtual IMapControlDataEntry * GetRecord(wxUint32 iIndex);
		virtual int Count();

	private:
		bool Load(wxString strBaseName);

		void Clear();

	private: // private member variables

		// the records themselves
		MapControlDataEntry_Std * m_psRecords;
		
		// the number of records
		int m_nRecords;
};

#endif
