/*
 *  LibRoadnav
 *  MapControlData_Tiles.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Manages the Tiger/Line data.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef MAPRECORDS_H
#define MAPRECORDS_H

#include <wx/datetime.h>

#include <map>
#include <vector>

#include "Point.h"
#include "MapControlDataEntry_Std.h"
#include "MapControlData_Foundation.h"

// this must be a power of two
#define LOADEDTILE_BLOCK_SIZE		64

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Implements a complete MapControlData, using tile-layers
///
//////////////////////////////////////////////////////////////////////////////
class MapControlData_Tiles : public MapControlData_Foundation
{
	public: // public functions
		MapControlData_Tiles();
		virtual ~MapControlData_Tiles();
	
		virtual void Clear();

		virtual void LoadRegion(const Point & ptTopLeft, const Point & ptBottomRight, const bool * pbVisibility, bool bClearExisting = true);

		virtual bool Save(MapControlDataImporter * pImporter, ProgressDialog * pdlgProgress = NULL, int iProgressStart = 0, int iProgressTicks = 1);

		double TileSize(ERecordType eType);
		
		wxDateTime GetLastUpdated();
	
	private: // private functions

		bool IsTileLoaded(const wxString & strName);
		void MarkTileLoaded(const wxString & strName);

	public: // public member variables
		
	private: // private member variables

		/// Last time tiles were modified
		static wxDateTime m_tLastUpdated;

		/// Contains m_tLastUpdated when the data was last loaded. Used to determine if the data on the disk
		/// has changed since the data was last loaded from the disk.
		wxDateTime m_tLastUpdatedForLoadedData;

		/// Array of strings indicating which tiles are loaded
		wxString * m_pvstrLoadedTiles;
		
		/// Number of tiles loaded into memory
		int m_nLoadedTiles;
		
		/// When searching m_pvstrLoadedTiles, the search starts with m_iLoadedTileSearchPos
		int m_iLoadedTileSearchPos;
		
		std::map<UniqueID,wxUint32> m_mapIDtoRecordNumber;
		
		static wxMutex m_mtxMaps;
};

#endif
